#
# spec file for package ongres-scram
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global		upstream_name    scram
%global		upstream_version 3.1
Name:           ongres-%{upstream_name}
Version:        %(echo %{upstream_version} | sed 's/-/~/g')
Release:        5.1
Summary:        Salted Challenge Response Authentication Mechanism - Java Implementation
License:        BSD-2-Clause
URL:            https://github.com/ongres/%{upstream_name}
Source0:        https://github.com/ongres/%{upstream_name}/archive/%{upstream_version}/%{upstream_name}-%{upstream_version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 11
BuildRequires:  maven-local
BuildRequires:  mvn(com.ongres.stringprep:saslprep) >= 2.2
BuildRequires:  mvn(org.jetbrains:annotations)
Requires:       mvn(com.ongres.stringprep:stringprep) >= 2.2
BuildArch:      noarch

%description
This is a Java implementation of SCRAM (Salted Challenge Response
Authentication Mechanism) which is part of the family of Simple
Authentication and Security Layer (SASL, RFC 4422) authentication
mechanisms. It is described as part of RFC 5802 and RFC7677.

%package client
Summary:        Client for %{name}

%description client
This package contains the client for %{name}

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}

%prep
%autosetup -p1 -n "%{upstream_name}-%{upstream_version}"
find \( -name '*.jar' -o -name '*.class' \) -delete

%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :flatten-maven-plugin
%pom_remove_plugin -r :maven-invoker-plugin
%pom_remove_dep -r :junit-bom

%{mvn_package} com.ongres.scram:scram-aggregator __noinstall
%{mvn_package} com.ongres.scram:scram-parent __noinstall

%pom_xpath_inject 'pom:plugin[pom:artifactId = "maven-jar-plugin"]/pom:configuration/pom:archive' '
<manifestEntries>
  <Multi-Release>true</Multi-Release>
</manifestEntries>
' scram-parent

%build
%{mvn_build} -s -f

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-scram-common
%license LICENSE

%files client -f .mfiles-scram-client
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Tue Apr  1 2025 Michael Calmer <mc@suse.com>
- Version 3.1
  - Update of the `saslprep` dependency to 2.2.
  - Full refactor of the `scram` java implementation, this release
    is compatible with Java 8+, but it's incompatible with previous
    releases
  - Fully rewrite the `ScramClient` allowing negotiation of
    channel-binding properly.
  - Create Multi-release Modular JARs, the modules names are:
  - `com.ongres.scram.common` for the common scram messages
  - `com.ongres.scram.client` for the scram client implementation
  - Add `StringPreparation.POSTGRESQL_PREPARATION`, for any error in
    SASL preparation, it falls back to return the raw string
  - Implementation of `tls-server-end-point` channel binding data
    extraction
  - Now the password is passed as a `char[]`
  - Remove the shaded Bouncy Castle pbkdf2 and base64 implementation
    used for Java 7 support
- remove ongres-scram-parent package
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Wed Sep 27 2023 Fridrich Strba <fstrba@suse.com>
- Remove dependency on findbugs
* Thu Mar  3 2022 Michael Calmer <mc@suse.com>
- update to version 2.1
  * Added standard SASLPrep (bsc#1196693)(jsc#SLE-23993, jsc#SLE-23994)
  * Failover to bouncy castle implementation of
    PBKDF2WithHmacSHA256 to support Oracle JDK 7
  * Updated saslprep to version 1.1 to remove a build dependency
    coming from stringprep module
* Thu Aug 27 2020 Fridrich Strba <fstrba@suse.com>
- Initial packaging of ongress-scram 1.0.0-beta.2
